Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(182)

Unified Diff: ui/views/controls/button/custom_button.h

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/bubble/bubble_delegate.cc ('k') | ui/views/controls/button/custom_button.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/controls/button/custom_button.h
diff --git a/ui/views/controls/button/custom_button.h b/ui/views/controls/button/custom_button.h
index 4d864b42abb058282ee69206867f78757b73c8cd..b818ffd09dd9f71602c65c41f3f51d5162d651e8 100644
--- a/ui/views/controls/button/custom_button.h
+++ b/ui/views/controls/button/custom_button.h
@@ -6,11 +6,11 @@
#define UI_VIEWS_CONTROLS_BUTTON_CUSTOM_BUTTON_H_
#include "base/memory/scoped_ptr.h"
-#include "ui/base/animation/animation_delegate.h"
#include "ui/base/events/event_constants.h"
+#include "ui/gfx/animation/animation_delegate.h"
#include "ui/views/controls/button/button.h"
-namespace ui {
+namespace gfx {
class ThrobAnimation;
}
@@ -24,7 +24,7 @@ class CustomButtonStateChangedDelegate;
// part of the focus chain. Call set_focusable(true) to make it part of the
// focus chain.
class VIEWS_EXPORT CustomButton : public Button,
- public ui::AnimationDelegate {
+ public gfx::AnimationDelegate {
public:
// The menu button's class name.
static const char kViewClassName[];
@@ -84,8 +84,8 @@ class VIEWS_EXPORT CustomButton : public Button,
virtual void GetAccessibleState(ui::AccessibleViewState* state) OVERRIDE;
virtual void VisibilityChanged(View* starting_from, bool is_visible) OVERRIDE;
- // Overridden from ui::AnimationDelegate:
- virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE;
+ // Overridden from gfx::AnimationDelegate:
+ virtual void AnimationProgressed(const gfx::Animation* animation) OVERRIDE;
// Takes ownership of the delegate.
void set_state_changed_delegate(CustomButtonStateChangedDelegate* delegate) {
@@ -120,7 +120,7 @@ class VIEWS_EXPORT CustomButton : public Button,
ButtonState state_;
// Hover animation.
- scoped_ptr<ui::ThrobAnimation> hover_animation_;
+ scoped_ptr<gfx::ThrobAnimation> hover_animation_;
private:
// Should we animate when the state changes? Defaults to true.
« no previous file with comments | « ui/views/bubble/bubble_delegate.cc ('k') | ui/views/controls/button/custom_button.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698